
# Colino 📰

Your personal, hackable news digest generator.

**Colino currently only runs on macOS.**

For installation, usage, and documentation, visit: [https://colino.pages.dev](https://colino.pages.dev)
